| Title: | KONP Tests: Powerful K-Sample Tests for Right-Censored Data |
|---|---|
| Description: | The K-sample omnibus non-proportional hazards (KONP) tests are powerful non-parametric tests for comparing K (>=2) hazard functions based on right-censored data (Gorfine, Schlesinger and Hsu, 2020, <doi:10.1177/0962280220907355>). These tests are consistent against any differences between the hazard functions of the groups. The KONP tests are often more powerful than other existing tests, especially under non-proportional hazard functions. |
| Authors: | Matan Schlesinger [cre, aut], Malka Gorfine [aut] |
| Maintainer: | Matan Schlesinger <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.4 |
| Built: | 2026-06-02 08:00:07 UTC |
| Source: | https://github.com/matan-schles/konpsurv |
An implementation of the -sample omnibus non-proportional hazrds (KONP) tests.
The KONP tests are powerful non-parametric tests for comparing (>=2) hazard functions based on right-censored data. These tests are consistent against any differences between the hazard functions of the groups.
The KONP tests are often more powerful than other existing tests, especially under non-proportional hazard functions.
The package contains one function:
konp_test: non-parametric tests for equality of distributions using right-censored data.
Author and Maintainer: Matan Schlesinger [email protected]
Author: Malka Gorfine [email protected]
Gorfine, M., Schlesinger, M., & Hsu, L. (2020). -sample omnibus non-proportional hazards tests based on right-censored data. Statistical Methods in Medical Research, 29(10), 2830–2850.
doi:10.1177/0962280220907355
# gastric cancer data data(gastric) konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3)# gastric cancer data data(gastric) konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3)
Survival data from a trial comparing chemotherapy versus atezolizumab in the treatment of Urothelial carcinoma.
data(carcinoma)data(carcinoma)
A data frame with 625 observations (316 in the atezolizumab group and 309 chemotherapy group) with the following 3 columns:
the observed follow-up times in days.
the event indicators, 0=right censored, 1= event.
the group labels, 1 = atezolizumab, 2 = chemotherapy.
Powles T, Dura?n I, van der Heijden MS, et al. Atezolizumab versus chemotherapy in patients with platinum-treated locally advanced or metastatic urothelial carcinoma (IMvigor211): a multicentre, open-label, phase 3 randomised controlled trial. Lancet 2018; 391: 748-757.
Survival data from a trial comparing chemotherapy versus combined chemotherapy plus radiotherapy in the treatment of gastric cancer.
data(gastric)data(gastric)
A data frame with 90 observations (45 in each treatment group) with the following 3 columns:
the observed follow-up times in days.
the event indicators, 0=right censored, 1= event.
the group labels, 1 = chemotherapy, 2 = chemotherapy plus radiotherapy.
Stablein, D. M. and Koutrouvelis, I. A. (1985) A two-sample test sensitive to crossing hazards in uncensored and singly censored data. Biometrics 41, 643–652. (Page 649).
Gastrointestinal Tumor Study Group: Schein, P. D., Stablein, D. M., Bruckner, H. W., Douglass, H. O., Mayer, R., et al. (1982). A comparison of combination chemotherapy and combined modality therapy for locally advanced gastricarcinoma. Cancer 49, 1771-1777.
-sample Omnibus Non-Proportional hazards tests for right-censored data.KONP tests are -sample Omnibus Non-Proportional hazards tests for right-censored data.
konp_test(time, status, group, n_perm, n_impu = 1)konp_test(time, status, group, n_perm, n_impu = 1)
time |
A vector of the observed follow-up times. |
status |
A vector of event indicators, 0=right censored, 1= event at |
group |
A vector denoting the group labels, must contain at least two different values. |
n_perm |
The number of permutations. |
n_impu |
The number of imputations, for each imputation n_perm permutations will be executed. |
The KONP tests are powerful non-parametric tests for comparing (>=2) hazard functions based on right-censored data.
These tests are consistent against any differences between the hazard functions of the groups.
The KONP tests are often more powerful than other existing tests, especially under non-proportional hazard functions.
Three test statistics and their respective p-values are returned:
pv_chisq - returns the p-value based on the KONP test chi-square statistic. pv_lr - returns the p-value based on the KONP test likelihood ratio statistic. pv_cauchy - returns the p-value based on the KONP-based Cauchy-combination test statistic. chisq_test_stat - returns the KONP test chi-squared test statistic. lr_test_stat - returns the KONP test likelihood-ratio test statistic. cauchy_test_stat - returns the KONP-based Cauchy-combination test statistic.
# gastric cancer data data(gastric) konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3)# gastric cancer data data(gastric) konp_test(gastric$time, gastric$status, gastric$group, n_perm=10^3)